<?php
/**
 * asr Theme Setup & Functions.
 * @package Frontier
 *
 */
$asr_version = "1.2.4";

/*-------------------------------------
	Setup Theme Options
--------------------------------------*/
if ( !function_exists( 'optionsframework_init' ) ) {
	define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/includes/options-framework/' );
	require_once dirname( __FILE__ ) . '/includes/options-framework/options-framework.php';
}

function asr_option( $name, $default = false ) {
	$config = get_option( 'optionsframework' );

	if ( ! isset( $config['id'] ) ) return $default;
	$options = get_option( $config['id'] );
	if ( isset( $options[$name] ) ) return $options[$name];
	
	return $default;
}

	


/*-------------------------------------
	Register Styles & Scripts
--------------------------------------*/
function asr_enqueue_styles() {
	global $frontier_version;

	wp_enqueue_style( 'asr-font', '//fonts.googleapis.com/css?family=Roboto+Condensed:400,700|Arimo:400,700', array(), false );
	wp_enqueue_style( 'asr-icon', get_template_directory_uri() . '/includes/genericons/genericons.css', array(), $asr_version );
	wp_enqueue_style( 'asr-main', get_stylesheet_uri(), array(), $asr_version );

	if ( asr_option('responsive_disable', 0) != 1 )
		wp_enqueue_style( 'asr-responsive', get_template_directory_uri() . '/responsive.css', array(), $asr_version );
	if ( asr_option('slider_enable') == 1 )
		wp_enqueue_script( 'basic-slider', get_template_directory_uri() . '/includes/slider/bjqs-1.3.min.js', array( 'jquery' ), $asr_version, true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	wp_enqueue_script( 'jquery' );
}
add_action( 'wp_enqueue_scripts', 'asr_enqueue_styles' );


/*-------------------------------------
	ASR Theme Setup
--------------------------------------*/
function asr_theme_setup() {
	global	$content_width, $asr_container, $asr_header, $asr_content;

	// Get needed values for layout
	asr_get_layout_values();

	load_theme_textdomain( 'asr', get_template_directory() . '/languages' );

	register_nav_menu( 'asr-menu-top', __( 'Top Bar', 'asr' ) );

	register_nav_menu( 'asr-menu-primary', __( 'Primary', 'asr' ) );

	add_theme_support( 'automatic-feed-links' );

	add_theme_support( 'title-tag' );

	add_theme_support( 'custom-background', array(
		'default-color' => '505050',
		'default-image' => get_template_directory_uri() . '/images/honeycomb.png',
	) );

	add_theme_support( 'custom-header', array(
		'default-image'          => '',
		'random-default'         => false,
		'width'                  => $asr_container,
		'height'                 => $asr_header,	
		'flex-height'            => true,
		'flex-width'             => true,
		'header-text'            => false,
		'uploads'                => true,
	) );

	add_theme_support( 'post-thumbnails' );

	add_image_size( 'thumb-200x120', 200, 120, true );

	add_theme_support( 'html5', array( 'search-form', 'comment-form' ) );

	add_filter( 'widget_text', 'do_shortcode' );

	add_action( 'wp_head', 'asr_meta_charset', 0 );
	add_action( 'wp_head', 'asr_meta_viewport', 0 );
	add_action( 'wp_head', 'asr_link_profile', 1 );
	add_action( 'wp_head', 'asr_link_pingback', 1 );

	// Print CSS for layout
	add_action( 'wp_head', 'asr_print_layout' );
	add_action( 'wp_head', 'asr_print_layout_page' );

	// Print CSS for header image
	if ( !( get_header_image() == '' ) ) add_action( 'wp_head', 'asr_header_image' );

	// Print CSS for colors
	if ( asr_option('colors_enable') == 1 ) add_action( 'wp_head', 'asr_custom_colors' );

	// Print Custom CSS if available
	if ( asr_option('custom_css') ) add_action( 'wp_head', 'asr_print_custom_css', 990 );

	if ( asr_option('favicon') ) add_action( 'wp_head', 'asr_favicon', 8 );
	if ( asr_option('head_codes') ) add_action( 'wp_head', 'asr_head_codes' );
	if ( asr_option('editor_style_disable') != 1 ) asr_editor_style();

	if ( asr_option('responsive_disable', 0) != 1 ) add_action( 'wp_footer', 'asr_menu_style_script', 18 );

	if ( asr_option('slider_enable') == 1 ) {
		asr_show_slider();
		add_action( 'wp_footer', 'asr_slider_script', 20 );
		if ( asr_option('slider_stretch') == 'stretch' ) add_action( 'wp_head', 'asr_slider_stretch' );
	}
}
add_action( 'after_setup_theme', 'asr_theme_setup' );


/*-------------------------------------
	ASR WP Title
--------------------------------------*/
if ( ! function_exists( '_wp_render_title_tag' ) ) {
	add_action( 'wp_head', 'asr_wp_title_render', 1 );
}

function asr_wp_title_render() {
?>
<title><?php wp_title( '|', true, 'right' ); ?></title>
<?php
}


/*----------------------------------------
	Custom Entries to the Admin Bar
-----------------------------------------*/
function asr_admin_bar_menu() {
	global $wp_admin_bar;

	if ( current_user_can( 'edit_theme_options' ) ) {
		$wp_admin_bar->add_menu( array(
			'parent' => false,
			'id' => 'asr_admin_bar', 
			'title' => __('ASR Options', 'asr'), 
			'href' => admin_url('themes.php?page=asr-options') ) );

		$wp_admin_bar->add_menu( array(
			'parent' => 'appearance',
			'id' => 'theme_editor_admin_bar', 	
			'title' => __('Editor', 'asr'), 
			'href' => admin_url('theme-editor.php') ) );

		$wp_admin_bar->add_menu( array(
			'parent' => 'appearance',
			'id' => 'plugins_admin_bar', 	
			'title' => __('Plugins', 'asr'), 
			'href' => admin_url('plugins.php') ) );
	}
}
add_action( 'admin_bar_menu', 'asr_admin_bar_menu', 88 );


/*----------------------------------------
	Register Sidebars
-----------------------------------------*/
function asr_register_sidebars() {
	register_sidebar( array(
		'name' 			=> __('Sidebar &ndash; Left', 'asr'),
		'id' 			=> 'widgets_sidebar_left',
		'description'	=> __('For layouts and templates with a left sidebar.', 'asr'),
		'before_widget' => '<div id="%1$s" class="widget-sidebar asr-widget %2$s">',
		'after_widget' 	=> '</div>',
		'before_title' 	=> '<h4 class="widget-title">',
		'after_title' 	=> '</h4>') );

	register_sidebar( array(
		'name' 			=> __('Sidebar &ndash; Right', 'asr'),
		'id' 			=> 'widgets_sidebar_right',
		'description'	=> __('For layouts and templates with a right sidebar.', 'asr'),
		'before_widget' => '<div id="%1$s" class="widget-sidebar asr-widget %2$s">',
		'after_widget' 	=> '</div>',
		'before_title' 	=> '<h4 class="widget-title">',
		'after_title' 	=> '</h4>') );

	asr_register_sidebars_extra();
}
add_action( 'widgets_init', 'asr_register_sidebars' );


function asr_register_sidebars_extra() {
	$widget_areas = asr_option('widget_areas');

	if ( $widget_areas['body'] == 1 ) {
		register_sidebar( array(
			'name' 			=> __('Body', 'asr'),
			'id' 			=> 'widgets_body',
			'description'	=> __('Widgets outside of the container. If used, you\'ll have to position the widgets with css.', 'asr'),
			'before_widget' => '<div id="%1$s" class="widget-body asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}

	if ( !isset($widget_areas['header']) || $widget_areas['header'] == 1 ) {
		register_sidebar( array(
			'name' 			=> __('Header', 'asr'),
			'id' 			=> 'widgets_header',
			'description'	=> __('Widgets to appear on the header. Ideal for horizontal ads or banners.', 'asr'),
			'before_widget' => '<div id="%1$s" class="widget-header asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}

	if ( $widget_areas['below_menu'] == 1 ) {
		register_sidebar( array(
			'name' 			=> __('Below Menu', 'sr'),
			'id' 			=> 'widgets_below_menu',
			'description'	=> __('Full-width widgets that appear under the main menu. Ideal for horizontal ads or banners.', 'asr'),
			'before_widget' => '<div id="%1$s" class="widget-below-menu asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}

	if ( $widget_areas['before_content'] == 1 ) {
		register_sidebar(array(
			'name' 			=> __('Before Content', 'asr'),
			'id' 			=> 'widgets_before_content',
			'before_widget' => '<div id="%1$s" class="widget-before-content asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}

	if ( $widget_areas['after_content'] == 1 ) {
		register_sidebar( array(
			'name' 			=> __('After Content', 'asr'),
			'id' 			=> 'widgets_after_content',
			'before_widget' => '<div id="%1$s" class="widget-after-content asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}

	if ( !isset($widget_areas['footer']) || $widget_areas['footer'] == 1 ) {
		register_sidebar( array(
			'name' 			=> __('Footer', 'asr'),
			'id' 			=> 'widgets_footer',
			'description'	=> __('You can set the number of widgets per row on the options page. 1, 2, 3, 4, 5 or 6 columns.', 'asr'),
			'before_widget' => '<div id="%1$s" class="widget-footer asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}

	if ( !isset($widget_areas['post_header']) || $widget_areas['post_header'] == 1 ) {
		register_sidebar( array(
			'name' 			=> __('Post &ndash; Header', 'asr'),
			'id' 			=> 'widgets_before_post',
			'before_widget' => '<div id="%1$s" class="widget-before-post asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}

	if ( !isset($widget_areas['post_before_content']) || $widget_areas['post_before_content'] == 1 ) {
		register_sidebar( array(
			'name' 			=> __('Post &ndash; Before Content', 'asr'),
			'id' 			=> 'widgets_before_post_content',
			'before_widget' => '<div id="%1$s" class="widget-before-post-content asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}

	if ( !isset($widget_areas['post_after_content']) || $widget_areas['post_after_content'] == 1 ) {
		register_sidebar( array(
			'name' 			=> __('Post &ndash; After Content', 'asr'),
			'id' 			=> 'widgets_after_post_content',
			'before_widget' => '<div id="%1$s" class="widget-after-post-content asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}

	if ( !isset($widget_areas['post_footer']) || $widget_areas['post_footer'] == 1 ) {
		register_sidebar( array(
			'name' 			=> __('Post &ndash; Footer', 'asr'),
			'id' 			=> 'widgets_after_post',
			'before_widget' => '<div id="%1$s" class="widget-after-post asr-widget %2$s">',
			'after_widget' 	=> '</div>',
			'before_title' 	=> '<h4 class="widget-title">',
			'after_title' 	=> '</h4>') );
	}
}

/*-------------------------------------
	Add Common <head> Items
--------------------------------------*/
function asr_meta_charset() {
	echo '<meta charset="' . get_bloginfo( 'charset' ) . '" />' . "\n";
}

function asr_meta_viewport() {
	echo '<meta name="viewport" content="initial-scale=1.0" />' . "\n";
}

function asr_link_profile() {
	echo '<link rel="profile" href="http://gmpg.org/xfn/11" />' . "\n";
}

function asr_link_pingback() {
	echo '<link rel="pingback" href="' . get_bloginfo( 'pingback_url' ) . '" />' . "\n";
}


/*-------------------------------------
	Get Layout Values - Theme Setup
--------------------------------------*/
function asr_get_layout_values() {
	global	$content_width, $asr_container, $asr_header, $asr_content, $asr_side_left, $asr_side_right, $footer_widget_css,
			$asr_2col_content, $asr_2col_sidebar, $asr_3col_content, $asr_3col_sidebar1, $asr_3col_sidebar2;

	$asr_container = asr_option('width_container', 960);

	$asr_header = asr_option('header_height', 140);

	$asr_2col_content = asr_option('width_two_column', 65);
	$asr_2col_sidebar = 100 - asr_option('width_two_column', 65);
	
	$asr_3col_value = explode( '-', asr_option('width_three_column', '25-75') );
	$asr_3col_content = $asr_3col_value[1] - $asr_3col_value[0];
	$asr_3col_sidebar1 = $asr_3col_value[0];
	$asr_3col_sidebar2 = 100 - $asr_3col_value[1];

	switch ( asr_option('column_layout', 'col-cs') ) {
		case 'col-c'  :
			$asr_content = 100;
			$content_width = $asr_container - 42;
			break;

		case 'col-sc' :
		case 'col-cs' :
			$asr_content = $asr_2col_content;
			$asr_side_left = $asr_2col_sidebar;
			$asr_side_right = $asr_2col_sidebar;
			$content_width = intval( $asr_container * ( $asr_content / 100 ) ) - 38;
			break;

		case 'col-ssc' :
		case 'col-css' :
		case 'col-scs' :
			$asr_content = $asr_3col_content;
			$asr_side_left = $asr_3col_sidebar1;
			$asr_side_right = $asr_3col_sidebar2;
			$content_width = intval( $asr_container * ( $asr_content / 100 ) ) - 38;
			break;
	}
}

/*-------------------------------------
	Layout CSS - Theme Setup
--------------------------------------*/
function asr_print_layout() {
	global	$asr_version, $asr_container,
			$asr_content, $asr_side_left, $asr_side_right;

	$header_min = ( asr_option('header_logo') ) ? 0 : asr_option('header_height', 140);
echo '
<meta property="ASR Theme" content="' . $asr_version . '" />
<style type="text/css" media="screen">
	#container 	{width: ' . $asr_container . 'px;}
	#header 	{min-height: ' . $header_min . 'px;}
	#content 	{width: ' . $asr_content . '%;}
	#sidebar-left 	{width: ' . $asr_side_left . '%;}
	#sidebar-right 	{width: ' . $asr_side_right . '%;}
</style>' . "\n";
}

/*-------------------------------------
	Layout CSS for Pages - Theme Setup
--------------------------------------*/
function asr_print_layout_page() {
	global	$asr_2col_content, $asr_2col_sidebar,
			$asr_3col_content, $asr_3col_sidebar1, $asr_3col_sidebar2;
echo '
<style type="text/css" media="screen">
	.page-template-page-cs-php #content, .page-template-page-sc-php #content {width: ' . $asr_2col_content . '%;}
	.page-template-page-cs-php #sidebar-left, .page-template-page-sc-php #sidebar-left,
	.page-template-page-cs-php #sidebar-right, .page-template-page-sc-php #sidebar-right {width: ' . $asr_2col_sidebar . '%;}
	.page-template-page-scs-php #content {width: ' . $asr_3col_content . '%;}
	.page-template-page-scs-php #sidebar-left {width: ' . $asr_3col_sidebar1 . '%;}
	.page-template-page-scs-php #sidebar-right {width: ' . $asr_3col_sidebar2 . '%;}
</style>' . "\n\n";
}

/*-------------------------------------
	Header BG CSS - Theme Setup
--------------------------------------*/
function asr_header_image() {
	global $asr_container, $asr_header;
echo
'<style type="text/css" media="screen">
	#header {
		background-image: url(\'' . get_header_image() . '\');
		background-size: ' . $asr_container . 'px ' . $asr_header . 'px;
	}
</style>' . "\n\n";
}

/*-------------------------------------
	Custom Colors CSS - Theme Setup
--------------------------------------*/
function asr_custom_colors() {
	$colormotif = asr_option('color_motif');
	$colortopbar = asr_option('color_top_bar');
	$colorheader = asr_option('color_header');
	$colormenu = asr_option('color_menu_main');
	$colorbottombar = asr_option('color_bottom_bar');
	$colorlinks = asr_option('color_links');
	$colorlinkshover = asr_option('color_links_hover');

echo
'<style type="text/css" media="screen">
	#header {background-color:' . $colorheader . ';}
	#nav-main {background-color:' . $colormenu . ';}
	#nav-main .nav-main {border-left: 1px solid ' . asr_alter_color( $colormenu, -40 ) . '; border-right: 1px solid ' . asr_alter_color( $colormenu, 30 ) . ';}
	#nav-main .nav-main > li, #nav-main .nav-main > ul > .page_item {border-left: 1px solid ' . asr_alter_color( $colormenu, 30 ) . '; border-right: 1px solid ' . asr_alter_color( $colormenu, -40 ) . ';}
	#top-bar {background-color:' . $colortopbar . ';}
	#bottom-bar {background-color:' . $colorbottombar . ';}
	.blog-view, .comment-author-admin > .comment-body, .bypostauthor > .comment-body {border-top: 6px solid ' . $colormotif . ';}
	.page-nav > *, .comment-nav > *, .author-info .title, .comment-reply-link, .widget-title,
	.widget_search .search-submit, .widget_calendar caption {background-color:' . $colormotif . ';}
	.genericon {color:' . $colormotif . ';}
	a {color:' . $colorlinks . ';}
	a:hover {color:' . $colorlinkshover . ';}
</style>' . "\n\n";
}

function asr_alter_color( $hex, $steps ) {
    $steps = max(-255, min(255, $steps));

    $hex = str_replace('#', '', $hex);
    if (strlen($hex) == 3) {
        $hex = str_repeat(substr($hex,0,1), 2).str_repeat(substr($hex,1,1), 2).str_repeat(substr($hex,2,1), 2);
    }

    $r = hexdec(substr($hex,0,2));
    $g = hexdec(substr($hex,2,2));
    $b = hexdec(substr($hex,4,2));

    $r = max(0,min(255,$r + $steps));
    $g = max(0,min(255,$g + $steps));  
    $b = max(0,min(255,$b + $steps));

    $r_hex = str_pad(dechex($r), 2, '0', STR_PAD_LEFT);
    $g_hex = str_pad(dechex($g), 2, '0', STR_PAD_LEFT);
    $b_hex = str_pad(dechex($b), 2, '0', STR_PAD_LEFT);

    return '#'.$r_hex.$g_hex.$b_hex;
}

/*-------------------------------------
	Custom CSS - Theme Setup
--------------------------------------*/
function asr_print_custom_css() {
	echo "\n" . '<!-- Custom CSS -->' . "\n" . '<style type="text/css" media="screen">' . "\n";
	echo asr_option('custom_css');
	echo "\n" . '</style>' . "\n" . '<!-- Custom CSS End -->' . "\n\n";
}

/*-------------------------------------
	Favicon - Theme Setup
--------------------------------------*/
function asr_favicon() {
	echo '<link rel="icon" href="' . esc_url( asr_option('favicon') ) . '" type="image/favicon.png" />' . "\n";
}

/*-------------------------------------
	Custom Codes - Theme Setup
--------------------------------------*/
function asr_head_codes() {
	echo '<!-- Custom Head Codes -->' . "\n";
	echo asr_option('head_codes');
	echo "\n" . '<!-- Custom Head Codes End -->' . "\n\n";
}

/*----------------------------------------
	Post Editor Style - Theme Setup
-----------------------------------------*/
function asr_editor_style() {
	add_editor_style();
	add_action( 'before_wp_tiny_mce', 'asr_tinymce_width' );
}

function asr_tinymce_width() {
	global $content_width, $asr_container, $asr_2col_content, $asr_3col_content;

	$tinymce_width = $content_width;

	switch ( get_page_template_slug() ) {
		case 'page-c.php'		:
		case 'page-blank.php'	:
			$tinymce_width = $asr_container - 42;
			break;

		case 'page-sc.php'	:
		case 'page-cs.php'	:
			$tinymce_width = intval( $asr_container * ( $asr_2col_content / 100 ) ) - 38;
			break;

		case 'page-scs.php'	:
			$tinymce_width = intval( $asr_container * ( $asr_3col_content / 100 ) ) - 38;
			break;
	}

?>
<script type="text/javascript">
jQuery( document ).ready( function() {
	var editor_width = '.mceContentBody {width: <?php echo $tinymce_width; ?>px;}';
	var checkInterval = setInterval(
		function() {
			if ( 'undefined' !== typeof( tinyMCE ) ) {
				if ( tinyMCE.activeEditor && ! tinyMCE.activeEditor.isHidden() ) {
					jQuery( '#content_ifr' ).contents().find( 'head' ).append( '<style>' + editor_width + '</style>' );
					clearInterval( checkInterval );
				}
			}
	}, 500 );
} );
</script>
<?php
}

function asr_menu_style_script() {
	if ( asr_option('main_menu_style', 'stack') == 'stack' ) : ?>
<script type="text/javascript">
jQuery(document).ready(function($) {
	$('.menu-item-has-children').click(function(){
		$('.nav-main > .menu-item-has-children').not(this).removeClass('toggle-on');
		$(this).not().parents().removeClass('toggle-on');
		$(this).toggleClass('toggle-on');
	});
});
</script>
<?php else : ?>
<script type="text/javascript">
jQuery(document).ready(function($) {
	$('#nav-main .drop-toggle').click(function(){
		$('#nav-main').toggleClass('dropped');
	});
});
</script>
<?php endif;
}

/*-------------------------------------
	Slider Template - Theme Setup
--------------------------------------*/
function asr_show_slider() {
	if ( asr_option('slider_position') == 'before_main' ) {
		add_action('asr_before_main', 'asr_slider_on_main'); }
	else {
		add_action('asr_before_content', 'asr_slider_on_content');
	}
}

function asr_slider_on_main() {
	if ( is_home() || is_front_page() ) {
		echo '<div id="slider" class="slider-main">';
		get_template_part('slider');
		echo '</div>';
	}
}

function asr_slider_on_content() {
	if ( is_home() || is_front_page() ) {
		echo '<div id="slider" class="slider-content">';
		get_template_part('slider');
		echo '</div>';
	}
}

/*-------------------------------------
	Slider Script - Theme Setup
--------------------------------------*/
function asr_slider_script() {
	global $asr_container, $asr_content;
	$slider_width = asr_option('slider_position') == 'before_main' ? $asr_container : $asr_container * ( $asr_content / 100 );
?>
<script type="text/javascript">
jQuery( document ).ready( function($) {
	$( '#basic-slider' ).bjqs( {
		animtype : 'fade',
		width : <?php echo $slider_width; ?>,
		height : <?php echo asr_option('slider_height'); ?>,
		animduration : <?php echo asr_option('slider_slide_speed'); ?>,
		animspeed : <?php echo asr_option('slider_pause_time'); ?>,
		automatic : true,
		showcontrols : true,
		nexttext : '<span class="slider-next"></span>',
		prevtext : '<span class="slider-prev"></span>',
		showmarkers : false,
		usecaptions : true,
		responsive : true
	} );
} );
</script>
<?php
}

/*-------------------------------------
	Slider Stretch - Theme Setup
--------------------------------------*/
function asr_slider_stretch() {
	echo '<style type="text/css">.bjqs-slide a, .bjqs-slide img {height: 100%; width: 100%;}</style>' . "\n\n";
}

/*-------------------------------------
	Attachment Page Image
--------------------------------------*/
function asr_prepend_attachment( $content ) {
	$attachment_image = '<div class="attachment">';
	$attachment_image .= wp_get_attachment_link( 0, apply_filters( 'asr_attachment_image_size', 'full' ), false );
	$attachment_image .= '<p class="wp-caption-text">' . get_post()->post_excerpt . '</p>';
	$attachment_image .= '</div>';

	if ( wp_attachment_is_image() )
		return $attachment_image;
	else
		return $content;
}
add_filter( 'prepend_attachment', 'asr_prepend_attachment' );


/*-------------------------------------
	Callback: Comment Markup
--------------------------------------*/
function asr_comments( $comment, $args, $depth ) {
	$tag = ( 'div' === $args['style'] ) ? 'div' : 'li';
?>
<<?php echo $tag; ?> id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
<div id="div-comment-<?php comment_ID(); ?>" class="comment-body">

<?php if ( get_comment_type() == 'comment' || !$args['short_ping'] ) : ?>

	<div class="comment-meta">
		<div class="comment-author">
			<?php if ( 0 != $args['avatar_size'] ) echo get_avatar( $comment, $args['avatar_size'], '', get_comment_author() ); ?>
			<div class="link"><?php echo get_comment_author_link(); ?></div>
		</div>

		<div class="comment-metadata">
			<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID, $args ) ); ?>">
				<time datetime="<?php comment_time( 'c' ); ?>">
					<?php printf( _x( '%1$s at %2$s', '1: date, 2: time', 'asr' ), get_comment_date(), get_comment_time() ); ?>
				</time>
			</a>
			<?php edit_comment_link( __( 'Edit', 'asr' ), '<span class="edit-link">', '</span>' ); ?>
		</div>

		<?php if ( '0' == $comment->comment_approved ) : ?>
			<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'asr' ); ?></p>
		<?php endif; ?>
	</div>

	<div class="comment-content"><?php comment_text(); ?></div>

	<div class="reply"><?php comment_reply_link( array_merge( $args, array( 'add_below' => 'div-comment', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?></div>

<?php else : ?>

	<?php _e( 'Pingback:', 'asr' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( 'Edit', 'asr' ), '<span class="edit-link">', '</span>' ); ?>

<?php endif; ?>

</div>
<?php
}